/*
* CLIF is a Load Injection Framework
* Copyright (C) 2005 France Telecom R&D
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
* License as published by the Free Software Foundation; either
* version 2 of the License, or (at your option) any later version.
*
* This library is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public
* License along with this library; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*
* Contact: clif@ow2.org
*/

package org.ow2.clif.storage.api;

import java.io.Serializable;


/**
 * This interface specifies methods to be implemented by a blade descriptor, whose role is
 * to designate and describe a single blade involved in a given test run.
 * @author Bruno Dillenseger
 */
public interface BladeDescriptor extends Serializable
{
	/**
	 * @return the CLIF server name who has run this blade.
	 */
	public String getServerName();

	/**
	 * @return the argument set for this blade
	 */
	public String getArgument();

	/**
	 * @return the classname of this injector blade, or the resource type name for this probe blade.
	 */
	public String getClassname();

	/**
	 * @return the comment associated to this blade
	 */
	public String getComment();

	/**
	 * @return the identifier for this blade (unique for a given test run)
	 */
	public String getId();

	/**
	 * @return true if this blade is a probe, false otherwise.
	 */
	public boolean isProbe();

	/**
	 * @return true if this blade is an injector, false otherwise.
	 */
	public boolean isInjector();

	/**
	 * @return labels of the events generated by this blade
	 * (each event type is identified by a specific label).
	 */
	public String[] getEventTypeLabels();
}
