/*
* CLIF is a Load Injection Framework
* Copyright (C) 2004, 2011 France Telecom R&D
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
* License as published by the Free Software Foundation; either
* version 2 of the License, or (at your option) any later version.
*
* This library is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public
* License along with this library; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*
* Contact: clif@ow2.org
*/

package org.ow2.clif.storage.api;

import java.io.Serializable;


/**
 * Common/base interface for every event generated by blades
 * @author Bruno Dillenseger
 */
public interface BladeEvent extends Comparable<Object>, Serializable
{
	/**
	 * @return a label uniquely designating this class of event
	 */
	public String getTypeLabel();

	/**
	 * @return the date of this event
	 */
	public long getDate();

	/**
	 * @param dateOrigin the origin date in milliseconds (since 1st January 1970). This value
	 * is subtracted from the event date before printing, thus allowing a change of date origin.
	 * @param separator the separator string to be used to separate the event values
	 * @return a text line describing this scenario event, consisting of values separated by the
	 * given separator string. The first field shall be an integer giving the date of the event.
	 */
	public String toString(long dateOrigin, String separator);

	/**
	 * @return an array of labels identifying the fields (attributes) hold by this event, in the
	 * same order as they are displayed by toString(long, String).
	 * @see #toString(long, String)
	 */
	public String[] getFieldLabels();

	/**
	 * @return the value as an Object hold by the given field.
	 * @param fieldLabel the label of the target field
	 */
	public Object getFieldValue(String fieldLabel);
}
